<?php
/**
 * Partner API Library
 * 
 * @copyright Copyright (c) 2020 Asseco Data Systems SA
 * @license license.txt
 */

/**
 * This class is for converting error codes to error descriptiions.
 * 
 * It is intended for internal use by the library rather than by a user.
 * 
 * @package operations
 */
class PartnerAPIError {
    
    /**
     * A set of status descriptions.
     * 
     * @var array
     */
    protected $texts_status = array(
        'en' => array(
            1 => 'Error occurred during processing',
            2 => 'Authentication data in requestHeader/authToken element are incorrect.'
        ),
        'pl' => array(
            1 => 'Wystąpił ogólny błąd podczas przetwarzania zamówienia. Należy skontaktować się z CERTUM w celu zdiagnozowania problemu.',
            3 => 'Dane autoryzacyjne w elemencie requestHeader/authToken nie są poprawne.'
        )
    );
    
    /**
     * A set of error descriptions.
     * 
     * @var array
     */
    protected $texts_error = array(
        'en' => array(
            1000 => 'CSR key length is too short.',
            1001 => 'Public key algorithm from CSR is not supported.',
            1002 => 'Element orderParameters/CSR not fund or empty.',
            1006 => 'The productCode element contains the code of the discontinued product.',
            1007 => 'Element quickOrder/SANEntries not found.',
            1008 => 'Element quickOrder/SANEntries/SANEntry/DNSName has wrong domain name.',
            1009 => 'Element quickOrder/requestorInfo not found.',
            1010 => 'Element quickOrder/orderParameters not found.',
            1011 => 'Element quickOrder/orderParameters/orderId not found.',
            1012 => 'Order ID is already taken.',
            1013 => 'Wrong order ID.',
            1014 => 'Element quickOrder/orderParameters/productCode not found.',
            1015 => 'Attribute CommonName not found.',
            1016 => 'Attribute Organization not found.',
            1019 => 'Attribute State from CSR-a not found.',
            1020 => 'Attribute Country not found.',
            1021 => 'Attribute EmailAddress not found.',
            1022 => 'Email address has errors.',
            1023 => 'Valu of orderParameters/customer element cannot be the same as requestHeader/authToken/username element.',
            1024 => 'Attribute CommonName has to be encoded as UTF8String.',
            1025 => 'Attribute EmailAddress has to be encoded as IA5String.',
            1026 => 'Attribute Country has to be encoded as PrintableString.',
            1027 => 'Attribute State has to be encoded as UTF8String.',
            1028 => 'Attribute Locality has to be encoded as UTF8String.',
            1029 => 'Attribute OrganizationUnit has to be encoded as UTF8String.',
            1030 => 'Attribute Organization has to be encoded as UTF8String.',
            1031 => 'Attribute CommonName has to be encoded as PrintableString.',
            1032 => 'Public key from CSR has already been used.',
            1033 => 'Order ID does not exist.',
            1037 => 'Address e-mail in element approverEmail has errors.',
            1038 => 'Element quickOrder/approvers/Approver/approverEmail not found.',
            1040 => 'Element quickOrder/approvers/Approver/approverMethod not found.',
            1042 => 'Domain verification method not supported.',
            1043 => 'Order ID contains characters that are not allowed: "&\'<>.',
            1044 => 'Certificate date is “from the past”.',
            1045 => 'Domain in CommonName is not present in SANEntries.',
            1046 => 'Only one domain in SANEntries element may contain asterix "*" in domain name.',
            1048 => 'Element taxIdentificationNumber not found or has incorrect value.',
            1049 => 'Cannot read public key from CSR.',
            1053 => 'Element requestorInfo/email not found.',
            1054 => 'Element requestorInfo/firstName not found.',
            1055 => 'Element requestorInfo/lastName not found.',
            1059 => 'Attribute Country not found.',
            1060 => 'Email address from requestorInfo/e-mail element is incorrect.',
            1063 => 'Public key from CSR is blacklisted.',
            1065 => 'Value from requestorInfo/lastName element exceeded 255 characters.',
            1066 => 'Value from requestorInfo/phone element exceeded 32 characters.',
            1069 => 'The certificate validity date provided in the shortenedValidityPeriod element exceeds the certificate validity period for the requested product.',
            1070 => 'Element organizationInfo/validityPeriod/notBefore not found.',
            1071 => 'Element organizationInfo/validityPeriod/notAfter not found.',
            1072 => 'Value from requestorInfo/firstName element exceeded 255 characters.',
            1075 => 'Partner is not allowed to order this product.',
            1076 => 'Element customer not found or empty.',
            1077 => 'Value from customer element exceeded 64 characters.',
            1078 => 'CSR in orderParameters/CSR element is incorrect.',
            1079 => 'Value from orderId element exceeded 50 characters.',
            1080 => 'Value from productCode element exceeded 3 characters.',
            1081 => 'Value from requestorInfo/email element exceeded 255 characters.',
            1083 => 'Value from taxIdentificationNumber element exceeded 32 characters.',
            1084 => 'Value from requestHeader/authToken/userName element exceeded 255 characters.',
            1085 => 'Value from SANEntries/SANEntry/DNSName element exceeded the number of characters allowed.',
            1087 => 'Value from approverEmail element exceeded 255 characters.',
            1088 => 'Value from orderParameters/language element exceeded 2 characters.',
            1089 => 'Value from orderParameters/userAgent element exceeded 255 characters.',
            1090 => 'Value from requestHeader/authToken/password element exceeded 255 characters.',
            1092 => 'Attribute JoISoPN not found.',
            1093 => 'Attribute JoISoCN not found.',
            1094 => 'Attribute JoILN not found.',
            1095 => 'Attribute SerialNumber not found.',
            1096 => 'Attribute JoISoCN exceeded 2 characters.',
            1097 => 'Attribute JoISoPN exceeded 128 characters.',
            1098 => 'Attribute JoILN exceeded 128 characters.',
            1099 => 'Attribute JoISoCN contains unsupported country code.',
            1100 => 'Attribute SerialNumber exceeded 64 characters.',
            1101 => 'Attribute CommonName exceeded 64 characters.',
            1102 => 'Attribute Organization exceeded 255 characters.',
            1103 => 'Attribute OrganizationalUnit exceeded 64 characters.',
            1104 => 'Attribute Locality exceeded 128 characters.',
            1105 => 'Attribute State exceeded 128 characters.',
            1106 => 'Attribute EmailAddress exceeded 255 characters.',
            1107 => 'Number of domains in SANEntries element exceeded allowed value for product.',
            1108 => 'Value in approverEmailPrefix does not match the prefix list.',
            1109 => 'Value from orderParameters/validityPeriod/notBefore element is greater than value from orderParameters/validityPeriod/notAfter element.',
            1110 => 'Date in fromDate is incorrect.',
            1111 => 'Date in toDate is incorrect.',
            1113 => 'Order status prevents sending email verification. The order is being processed or has been canceled. Certificate is being issued or is already issued. Verification emails hasn’t been sent.',
            1114 => 'All verification messages are still valid. Verification emails hasn’t been sent.',
            1115 => 'SANEntries/SANEntry/DNSName Element contains Widlcard domain which is not allowed for selected product.',
            1116 => 'CommonName contains Widlcard domain which is not allowed for selected product.',
            1117 => 'CommonName doesn’t contain Widlcard domain which is mandatory for selected product.',
            1118 => 'SANEntries/SANEntry/DNSName element doesn’t contain Widlcard domain which is mandatory for selected product.',
            1119 => 'Country attribute form CSR contains value not allowed for orders issued automatically.',
            1120 => 'Organization attribute form CSR contains value not allowed for orders issued automatically.',
            1121 => 'OrganizationUnit attribute form CSR contains value not allowed for orders issued automatically.',
            1122 => 'Locality attribute form CSR contains value not allowed for orders issued automatically.',
            1123 => 'State attribute form CSR contains value not allowed for orders issued automatically.',
            1124 => 'CommonName attribute form CSR contains value not allowed for orders issued automatically.',
            1125 => 'EmailAddress attribute form CSR contains value not allowed for orders issued automatically.',
            1126 => 'SerialNumber attribute has to be UTF8String encoded.',
            1127 => 'JoILN attribute has to be UTF8String encoded.',
            1128 => 'JoISoCN attribute has to be PrintableString encoded.',
            1129 => 'JoISoPN attribute has to be UTF8String encoded.',
            1131 => 'Element revokeCertificate/RevokeCertificateParameters not found.',
            1132 => 'Element revokeCertificate/RevokeCertificateParameters/serialNumber not found.',
            1133 => 'No certificate at given serial number.',
            1134 => 'Value in revokeCertificate/RevokeCertificateParameters/serialNumber element exceeded 64 characters.',
            1135 => 'Incorrect value in revokeCertificate/RevokeCertificateParameters/revocationReason.',
            1136 => 'To this order there is a certificate that is valid or will be valid. To cancel an order please revoke the certificate first.',
            1137 => 'Certficate to this order Has expired. Order cancel is not possible.',
            1138 => 'Request cannot be proceded. Please contact CERTUM.',
            1139 => 'It is impossible to cancel an order due to its status. Please try again later. If problem repeats please contact CERTUM.',
            1140 => 'Date in keyCompromitationDate element has to be YYYY-MM-DD.',
            1141 => 'Date in keyCompromitationDate element Has to be between certificate valid from date and current date.',
            1142 => 'Value of revokeCertificate/RevokeCertificateParameters/note element exceeded 250 characters.',
            1143 => 'Cannot revoke the certificate because certificate is during revocation process.',
            1144 => 'Cannot revoke the certificate because it has expired.',
            1145 => 'Cannot revoke the certificate because it has already been revoked.',
            1146 => 'Element revokeCertificate/RevokeCertificateParameters/serialNumber has to be HEX.',
            1147 => 'Element approvers/Approver for SANEntries/SANEntry/DNSName element not found.',
            1148 => 'Cannot place an order with private IP address.',
            1150 => 'Key length in CSR is too long.',
            1151 => 'Order has already been cancelled.',
            1152 => 'Element quickOrder/approvers/Approver/approverMethod not found.',
            1153 => 'Page number has to be from range [1 - 100].',
            1154 => 'Too many records were returned from the query.',
            1155 => 'Page not fund.',
            1156 => 'customer filed in orderParameters contains disallowed characters: "&\'<>.',
            1157 => 'quickOrder/SANEntries/SANEntry/DNSName element contains gTLD.',
            1159 => 'Certificate not found.',
            1160 => 'Certificate serial number is missing.',
            1161 => 'Serial number exceeded 64 characters.',
            1162 => 'Required parameters are missing (serial number or order identifier).',
            1163 => 'Request contains parameters that cannot occur simultaneously (certificate serial number and order identifier).',
            1164 => 'Certificate cannot be identified properly. Provide certificate serial number OR certificate in PEM form.',
            1165 => 'Certificate format is incorrect (certificate should be in PEM form).',
            1166 => 'Provided product code cannot be use as a renewal code.',
            1167 => 'Profile of the original certificate and renewal profile mismatch.',
            1168 => 'CN mismatch.',
            1169 => 'Customer mismatch.',
            1170 => 'Certificate issued from different account.',
            1172 => 'Request contains additional elements. Please verify request with documentation.',
            1173 => 'Provided data are equal to one provided Please use sendNotification to once again send verification emails.',
            1176 => 'Order status prevents sending domain verification. The order is being processed or has been canceled.Certificate is already issued. Required rgani is not possible.',
            1181 => 'Product code is incorrect for certificate issuance.',
            1182 => 'Code element not found.',
            1183 => 'Value in verifyDomain/code element exceeded 255 characters.',
            1184 => 'Verification code has expired.',
            1186 => 'Verification code is incorrect.',
            1191 => 'Validity period exceeds maximum validity period for chosen product.',
            1194 => 'orderSNICertificate/orderSNIParameters/CSR element not fund or empty.',
            1195 => 'orderSNICertificate/orderSNIParameters/CSR element doesn’t contain correct CSR.',
            1196 => 'Value from orderSNICertificate/orderSNIParameters/language element exceeded 2 characters.',
            1197 => 'orderSNICertificate/orderSNIParameters element not found.',
            1198 => 'orderSNICertificate/serialNumbers element not found.',
            1199 => 'At least one orderSNICertificate/serialNumbers/serialNumber element is required.',
            2000 => 'orderSNICertificate/serialNumbers/serialNumber cannot be empty.',
            2001 => 'Value in orderSNICertificate/serialNumbers/serialNumber element exceeded 64 characters.',
            2002 => 'orderSNICertificate/serialNumbers/serialNumber element has to be In HEX form.',
            2003 => 'Given certificate expired or was revoked.',
            2004 => 'One SNI certificate cannot contain another SNI Certificate.',
            2005 => 'None of provided certificate contain domain names.',
            2006 => 'orderSNICertificate/requestorInfo element not found.',
            2010 => 'orderSNICertificate/requestorInfo/email element not found.',
            2011 => 'orderSNICertificate/requestorInfo/firstName element not found.',
            2012 => 'orderSNICertificate/requestorInfo/lastName element not found.',
            2013 => 'orderSNICertificate/requestorInfo/phone element not found.',
            2016 => 'e-mail address from orderSNICertificate/requestorInfo/email element is incorrect.',
            2020 => 'Value from orderSNICertificate/requestorInfo/lastName element exceeded 255 characters.',
            2021 => 'Value from orderSNICertificate/requestorInfo/phone element exceeded 255 characters.',
            2024 => 'Value from orderSNICertificate/requestorInfo/firstName element exceeded 255 characters.',
            2025 => 'To order SNI Certificate use orderSNICertificate or modifySNICertificate method.',
            2026 => 'Value from orderSNICertificate/requestorInfo/email element exceeded 255 characters.',
            2027 => 'At least one modifySNICertificate/serialNumber or modifySNICertificate/X509Cert element has to be present.',
            2028 => 'modifySNICertificate/serialNumber element cannot be empty.',
            2029 => 'Value from modifySNICertificate/serialNumber element exceeded 64 characters.',
            2030 => 'modifySNICertificate/serialNumber element has to be In HEX form.',
            2031 => 'There is no certificate with provided serial number in modifySNICertificate/serialNumber element.',
            2032 => 'Only SNI certificates can be modified.',
            2033 => 'Incorrect certificate form in modifySNICertificate/X509Cert element.',
            2034 => 'Certificate is missing in modifySNICertificate/X509Cert element.',
            2035 => 'At least one modifySNICertificate/addSerialNumbers/serialNumber attribute is required.',
            2036 => 'modifySNICertificate/addSerialNumbers/serialNumber cannot be empty',
            2037 => 'Value from modifySNICertificate/addSerialNumbers/serialNumber element exceeded 64 characters.',
            2038 => 'modifySNICertificate/addSerialNumbers/serialNumber has to be in HEX form.',
            2039 => 'At least one modifySNICertificate/removeSerialNumbers/serialNumber attribute is required.',
            2040 => 'modifySNICertificate/removeSerialNumbers/serialNumber cannot be empty.',
            2041 => 'Value from modifySNICertificate/removeSerialNumbers/serialNumber element exceeded 64 characters.',
            2042 => 'modifySNICertificate/removeSerialNumbers/serialNumber has to be in HEX form.',
            2043 => 'Cannot and and remove the same certificate at the same time.',
            2044 => 'Cannot add certificate. Certificate not found.',
            2045 => 'Cannot add SNI certificate to be part of another SNI certificate.',
            2046 => 'Cannot add certificate that already is a part of SNI certificate.',
            2047 => 'Cannot remove certificate that is NOT a part of SNI certificate.',
            2048 => 'Resultant certificate contains no domains.',
            2049 => 'verifyOrderParameters/note not found or empty.',
            2050 => 'Value from verifyOrderParameters/note element exceeded 227 characters.',
            2051 => 'Incorrect value in CommonName field.',
            2052 => 'getExpiringCertificates/validityDaysLeft element not found or has incorrect value.',
            2053 => 'cancelParameters element not found.',
            2054 => 'changeApprovers/Approver element not found.',
            2055 => 'orderID element not found.',
            2056 => 'Order status don’t allow to add notes.',
            2057 => 'Value from toDate element cannot be emalier then value from fromDate element.',
            2058 => 'Attribute Locality or StateOfProvince not found.',
            2059 => 'Incorrect value in verificationNotificationEnabled element.',
            2061 => 'Incorrect value in renewCertificate/approvers/verificationNotificationEnabled element.',
            2063 => 'verifyOrder/verifyOrderParameters/documents/dokument element not found.',
            2064 => 'verifyOrder/verifyOrderParameters/documents/document/type element not found.',
            2065 => 'verifyOrder/verifyOrderParameters/documents/document/description element not found.',
            2066 => 'verifyOrder/verifyOrderParameters/documents/document/files element not found.',
            2067 => 'verifyOrder/verifyOrderParameters/documents/document/files/file element not found.',
            2068 => 'verifyOrder/verifyOrderParameters/documents/document/files/file/filename element not found.',
            2069 => 'verifyOrder/verifyOrderParameters/documents/document/files/file/content element not found.',
            2070 => 'verifyOrder/verifyOrderParameters/documents/document/files/file/content element should be in base64 form.',
            2080 => 'Request size limit has been exceeded.',
            2081 => 'fileName element cannot contain following characters: \ / : * ? " < > |',
            2082 => 'Value in fileName element has incorrect length. Allowed length are from 3 to 255 characters.',
            2083 => 'Incorrect type of document.',
            2085 => 'One of file in verifyOrder/verifyOrderParameters/documents/document/files/file element exceeded allowed size limit (30MB).',
            2088 => 'Part of domain name in SANEntries/SANEntry/DNSName element exceeded the number of characters allowed.',
            2089 => 'Algorithm is not configured.',
            2090 => 'There is an invalid value in hashAlgorithm element.',
            2091 => 'Invalid value in in element getProductList/HashAlgorithm.',
            2093 => 'Certificate date is from past.',
            2094 => 'The certificate does not meet the reissue conditions.',
            2095 => 'Element SANEntries/SANEntry/DNSName can not be empty.',
            2096 => 'Element serialNumber must be a hex string.',
            2097 => 'The ReissueCertificate/CSR element is not a valid CSR request.',
            2104 => 'The key compromising date may be specified only for the reason of cancellation of Key compromise.',
            2109 => 'Invalid key length.',
            2121 => 'The value from quickOrder/organizationInfo/verificationPhoneNumber element exceeded the acceptable size of 255 characters.',
            2122 => 'Reissue for products on SimplySign are unavailable.',
            2124 => 'Unsupported hash algorithm.',
            2125 => 'Incorrect signature in CSR.',
            2126 => 'Certificate reissue is not possible. Cannot reissue the same certificate again.',
            2127 => 'Incorrect value in certificateDetails element.',
            2128 => 'Incorrect value in certificateOrder element.',
            2129 => 'Incorrect value in orderStatus element.',
            2130 => 'Element SANEntries/SANEntry/DNSName contains domain existing already in issued certificate.',
            2131 => 'Certification request not found.',
            2137 => 'Incorrect value in businessCategory element.',
            2138 => 'Attribute businessCategory not found.',
            2139 => 'StreetAddress attribute not found.',
            2140 => 'Attribute streetAddress (ST) exceeded 64 characters.',
            2141 => 'Attribute streetAddress (ST) has to be UTF8String encoded.	',
            2142 => 'PostalCode attribute not found.',
            2143 => 'Attribute postalCode (P) exceeded 40 characters.',
            2144 => 'Attribute postalCode (P) has to be PrintableString.',
            2153 => 'Order with given number was not requested via API.',
            2154 => 'Incorrect value in postalCode (P) element.',
            2155 => 'Incorrect value in Jurisdiction of Incorporation State or Province Name JoISoPN element.',
            2156 => 'Incorrect value in stateOrProvinceName (SP).',
            2157 => 'Element approverMethod not found.',
            2158 => 'Too many elements. Only one approverEmail or approverEmailPrefix can be used.',
            2159 => 'Required approverEmailPrefix element not found.',
            2160 => 'Required approverEmail element not found.',
            2161 => 'VerifyDomain method does not support multidomain requests.',
            2162 => 'Element SANApprover not found.',
            2163 => 'The method does not support this product.',
            2164 => 'SerialNumber attribute is invalid.',
            2165 => 'Joiln attribute is invalid.',
            2166 => 'Locality attribute is invalid.',
            2167 => 'OrganizationUnit attribute is invalid.',
            2168 => 'Organization attribute is invalid.',
            2169 => 'StreetAddress attribute is invalid.',
            2170 => 'The value of Description element exceeded the acceptable size of 1000 characters.',
            2171 => 'Verification method not supported for IP address.',
            2172 => 'Revocation e-mail is the same as login.',
            2173 => 'The value of orderParameters/revocationContactEmail is invalid.',
            2175 => 'Attribute UnstructuredName or UnstructuredAddress has not been found.',
            2176 => 'Attribute UnstructuredName and UnstructuredAddress cannot be set together.',
            2177 => 'Attribute UnstructuredName is not PrintableString.',
            2178 => 'Attribute UnstructuredAddress is not PrintableString.',
            2179 => 'UnstructuredName attribute exceeded the acceptable size of 64 characters.',
            2180 => 'UnstructuredAddress attribute exceeded the acceptable size of 64 characters.',
            2181 => 'Attribute UnstructuredName is not valid domain name.',
            2182 => 'Attribute UnstructuredAddress is not valid IP address.',
            2183 => 'Attribute Description is not UTF8String.',
            2184 => 'Description attribute exceeded the acceptable size of 255 characters.',
            2185 => 'Date in shortenedValidityPeriod or ValidityPeriod/NotAfter is from the past',
            2186 => 'The verification method is not supported for orders with Wildcard domains.',
            2187 => 'Deprecated field ValidityPeriod in the request. To shorten the certificate validity period, use shortenedValidityPeriod.',
            2188 => 'Reissue request requires re-verification of domains. Due to regulatory changes on verification methods, the existing verifications cannot be reused.'
        ),
        'pl' => array(
            1000 => 'Długość klucza publicznego z CSR-a jest zbyt krótka.',
            1001 => 'Algorytm klucza publicznego z CSR-a nie jest obsługiwany.',
            1002 => 'Element orderParameters/CSR nie został odnaleziony lub jest pusty.',
            1006 => 'Element productCode zawiera kod produktu wycofanego z oferty.',
            1007 => 'Element quickOrder/SANEntries nie został odnaleziony.',
            1008 => 'Element quickOrder/SANEntries/SANEntry/DNSName zawiera błędną nazwę domeny.',
            1009 => 'Element quickOrder/requestorInfo nie został odnaleziony.',
            1010 => 'Element quickOrder/orderParameters nie został odnaleziony.',
            1011 => 'Element quickOrder/orderParameters/orderId nie został odnaleziony.',
            1012 => 'Numer zamówienia jest już zajęty.',
            1013 => 'Niepoprawny numer zamówienia.',
            1014 => 'Element quickOrder/orderParameters/productCode nie został odnaleziony.',
            1015 => 'Atrybut CommonName nie został znaleziony.',
            1016 => 'Atrybut Organization nie został znaleziony.',
            1019 => 'Atrybut State z CSR-a nie został znaleziony.',
            1020 => 'Atrybut Country nie został znaleziony.',
            1021 => 'Atrybut EmailAddress nie został znaleziony.',
            1022 => 'Atrybut EmailAddress zawiera błędy.',
            1023 => 'Wartość element orderParameters/customer nie może być taka sam jak wartość z elementu requestHeader/authToken/userName.',
            1024 => 'Atrybut CommonName musi być zakodowany jako UTF8String.',
            1025 => 'Atrybut EmailAddress musi być zakodowany jako IA5String.',
            1026 => 'Atrybut Country musi być zakodowany jako PrintableString.',
            1027 => 'Atrybut State musi być zakodowany jako UTF8String.',
            1028 => 'Atrybut Locality musi być zakodowany jako UTF8String.',
            1029 => 'Atrybut OrganizationUnit musi być zakodowany jako UTF8String.',
            1030 => 'Atrybut Organization musi być zakodowany jako UTF8String.',
            1031 => 'Atrybut CommonName musi być zakodowany jako PrintableString.',
            1032 => 'Klucz publiczny z CSR-a został już wykorzystany.',
            1033 => 'Zamówienie o podanym numerze nie istnieje.',
            1037 => 'Adres e-mail w elemencie approverEmail zawiera błędy.',
            1038 => 'Element quickOrder/approvers/Approver/approverEmail nie został odnaleziony.',
            1040 => 'Element quickOrder/approvers/Approver/approverMethod nie został odnaleziony.',
            1042 => 'Metoda weryfikacji domeny nie jest obsługiwana.',
            1043 => 'Identyfikator zamówienia zawiera niedozwolone znaki "&\'<>',
            1044 => 'Data wydania certyfikatu jest z przeszłości.',
            1045 => 'Domena podana w CommonName nie występuje na liście domen w elemencie SANEntries.',
            1046 => 'Tylko jedna domena w elemencie SANEntries może zawierać gwiazdkę w nazwie domeny.',
            1048 => 'Brakuje elementu taxIdentificationNumber lub element ma niepoprawną wartość.',
            1049 => 'Nie można odczytać klucza publicznego z CSR-a.',
            1053 => 'Element requestorInfo/email nie został odnaleziony.',
            1054 => 'Element requestorInfo/firstName nie został odnaleziony.',
            1055 => 'Element requestorInfo/lastName nie został odnaleziony.',
            1059 => 'Atrybut Country nie został znaleziony.',
            1060 => 'Adres e-mail z elementu requestorInfo/email nie jest poprawny.',
            1063 => 'Klucz publiczny z CSR-a znajduje się na czarnej liście.',
            1065 => 'Wartość z elementu requestorInfo/lastName przekroczyła dopuszczalny rozmiar 255 znaków.',
            1066 => 'Wartość z elementu requestorInfo/phone przekroczyła dopuszczalny rozmiar 32 znaków.',
            1069 => 'Data ważności certyfikatu podana w elemencie shortenedValidityPeriod przekracza dopuszczalny czas ważności certyfikatu dla żądanego produktu.',
            1070 => 'Brakuje elementu orderParameters/validityPeriod/notBefore.',
            1071 => 'Brakuje elementu orderParameters/validityPeriod/notAfter.',
            1072 => 'Wartość z elementu requestorInfo/firstName przekroczyła dopuszczalny rozmiar 255 znaków.',
            1075 => 'Partner nie ma uprawnień, aby złożyć zamówienia na dany produkt.',
            1076 => 'Brakuje elementu customer lub jest on pusty.',
            1077 => 'Wartość z elementu customer przekroczyła dopuszczalny rozmiar 64 znaków.',
            1078 => 'Element orderParameters/CSR nie jest poprawnym żądaniem CSR.',
            1079 => 'Wartość z elementu orderId przekroczyła dopuszczalny rozmiar 50 znaków.',
            1080 => 'Wartość z elementu productCode przekroczyła dopuszczalny rozmiar 3 znaków.',
            1081 => 'Wartość z elementu requestorInfo/email przekroczyła dopuszczalny rozmiar 255 znaków.',
            1083 => 'Wartość z elementu taxIdentificationNumber przekroczyła dopuszczalny rozmiar 32 znaków.',
            1084 => 'Wartość z elementu requestHeader/authToken/userName przekroczyła dopuszczalny rozmiar 255 znaków.',
            1085 => 'Wartość z elementu SANEntries/SANEntry/DNSName przekroczyła dopuszczalny rozmiar znaków.',
            1087 => 'Adres e-mail w elemencie approverEmail przekroczył dopuszczalny rozmiar 255 znaków.',
            1088 => 'Wartość z elementu orderParameters/language przekroczyła dopuszczalny rozmiar 2 znaków.',
            1089 => 'Wartość z elementu orderParameters/userAgent przekroczyła dopuszczalny rozmiar 255 znaków.',
            1090 => 'Wartość z elementu requestHeader/authToken/password przekroczyła dopuszczalny rozmiar 255 znaków.',
            1092 => 'Atrybut JoISoPN nie został znaleziony.',
            1093 => 'Atrybut JoISoCN nie został znaleziony.',
            1094 => 'Atrybut JoILN nie został znaleziony.',
            1095 => 'Atrybut SerialNumber nie został znaleziony.',
            1096 => 'Wartość atrybutu JoISoCN przekroczyła dopuszczalny rozmiar 2 znaków.',
            1097 => 'Wartość atrybutu JoISoPN przekroczyła dopuszczalny rozmiar 128 znaków.',
            1098 => 'Wartość atrybutu JoILN przekroczyła dopuszczalny rozmiar 128 znaków.',
            1099 => 'Wartość atrybutu JoISoCN zawiera nie obsługiwany kod kraju.',
            1100 => 'Wartość atrybutu SerialNumber przekroczyła dopuszczalny rozmiar 64 znaków.',
            1101 => 'Wartość atrybutu CommonName przekroczyła dopuszczalny rozmiar 64 znaków.',
            1102 => 'Wartość atrybutu Organization przekroczyła dopuszczalny rozmiar 255 znaków.',
            1103 => 'Wartość atrybutu OrganizationalUnit przekroczyła dopuszczalny rozmiar 64 znaków.',
            1104 => 'Wartość atrybutu Locality przekroczyła dopuszczalny rozmiar 128 znaków.',
            1105 => 'Wartość atrybutu State przekroczyła dopuszczalny rozmiar 128 znaków.',
            1106 => 'Wartość atrybutu EmailAddress przekroczyła dopuszczalny rozmiar 255 znaków.',
            1107 => 'Ilość domen podanych w elemencie SANEntries przekroczyła dopuszczalną ilość domen dla produktu.',
            1108 => 'Wartość z elementu approverEmailPrefix nie pasuje do listy prefixów.',
            1109 => 'Data podana w elemencie orderParameters/validityPeriod/notBefore jest większa niż data z elementu orderParameters/validityPeriod/notAfter.',
            1110 => 'Data podana w elemencie fromDate jest błędna.',
            1111 => 'Data podana w elemencie toDate jest błędna.',
            1113 => 'Status zamówienia uniemożliwia wysłanie weryfikacji email. Zamówienie jest w trakcie realizacji lub zostało anulowane. Dla podanego zamówienia certyfikat jest w trakcie wydania lub został już wydany. Maile weryfikacyjne nie zostały wysłane.',
            1114 => 'Dla podanego zamówienia wszystkie weryfikacje są jeszcze aktualne. Maile weryfikacyjne nie zostały wysłane.',
            1115 => 'Element SANEntries/SANEntry/DNSName zawiera domenę typu Wildcard, która nie jest dozwolona dla wybranego produktu.',
            1116 => 'CommonName zawiera domenę typu Wildcard, która nie jest dozwolona dla wybranego produktu.',
            1117 => 'CommonName nie zawiera domeny typu Wildcard, która jest wymagana dla tego produktu.',
            1118 => 'Element SANEntries/SANEntry/DNSName nie zawiera domeny typu Wildcard, która jest wymagana dla tego produktu.',
            1119 => 'Wartość atrybutu Country z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1120 => 'Wartość atrybutu Organization z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1121 => 'Wartość atrybutu OrganizationUnit z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1122 => 'Wartość atrybutu Locality z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1123 => 'Wartość atrybutu State z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1124 => 'Wartość atrybutu CommonName z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1125 => 'Wartość atrybutu EmailAddress z CSR jest niezgodna z dopuszczalnymi wartościami dla wniosków wystawianych automatycznie.',
            1126 => 'Atrybut SerialNumber musi być zakodowany jako UTF8String.',
            1127 => 'Atrybut JoILN musi być zakodowany jako UTF8String.',
            1128 => 'Atrybut JoISoCN musi być zakodowany jako PrintableString.',
            1129 => 'Atrybut JoISoPN musi być zakodowany jako UTF8String.',
            1131 => 'Element revokeCertificate/RevokeCertificateParameters nie został odnaleziony.',
            1132 => 'Element revokeCertificate/RevokeCertificateParameters/serialNumber nie został odnaleziony.',
            1133 => 'Brak certyfikatu o podanym numerze seryjnym.',
            1134 => 'Wartość elementu revokeCertificate/RevokeCertificateParameters/serialNumber przekroczyła dopuszczalny rozmiar 64 znaków.',
            1135 => 'Nieprawidłowa wartość elementu revokeCertificate/RevokeCertificateParameters/revocationReason',
            1136 => 'Do zamówienia został wydany certyfikat który ma status "ważny" lub dopiero uzyska status "ważny". Aby anulować zamówienie proszę unieważnić certyfikat.',
            1137 => 'Certyfikat do podanego numeru zamówienia już wygasł. Anulowanie wniosku nie jest możliwe.',
            1138 => 'Operacja nie może być wykonana. Skontaktuj się z CERTUM.',
            1139 => 'Status wniosku nie pozwala na jego odrzucenie. Jeśli błąd będzie się powtarzał skontaktuj się z CERTUM.',
            1140 => 'Data podana w elemencie keyCompromitationDate musi być w formacie YYYY-MM-DD.',
            1141 => 'Data podana w elemencie keyCompromitationDate musi zawierać się w przedziale pomiędzy datą początku ważności certyfikatu, a bieżącą datą.',
            1142 => 'Wartość elementu revokeCertificate/RevokeCertificateParameters/note przekroczyła dopuszczalny rozmiar 250 znaków.',
            1143 => 'Nie można unieważnić certyfikatu, ponieważ certyfikat jest w trakcie unieważniania.',
            1144 => 'Nie można unieważnić certyfikatu, ponieważ certyfikat wygasł.',
            1145 => 'Nie można unieważnić certyfikatu, ponieważ certyfikat został już unieważniony.',
            1146 => 'Element revokeCertificate/RevokeCertificateParameters/serialNumber musi być w postaci szesnastkowej.',
            1147 => 'Brak jednego lub więcej elementów approvers/Approver odpowiadających domenie z SANEntries/SANEntry/DNSName.',
            1148 => 'Nie można złożyć wniosku na lokalny adres IP.',
            1150 => 'Długość klucza publicznego z CSR-a jest zbyt długa.',
            1151 => 'Zamówienie zostało już anulowane.',
            1152 => 'Element quickOrder/approvers/Approver/approverMethod nie został odnaleziony.',
            1153 => 'Numer strony musi być z zakresu [1 - 100].',
            1154 => 'Zapytanie zwróciło zbyt dużą liczbę rekordów.',
            1155 => 'Strona z wynikami o podanym numerze nie istnieje.',
            1156 => 'Pole customer w orderParameters posiada niedozwolone znaki "&\'<>.',
            1157 => 'Element quickOrder/SANEntries/SANEntry/DNSName zawiera publiczną domenę najwyższego poziomu.',
            1159 => 'Certyfikat nie został odnaleziony.',
            1160 => 'Nie podano numeru seryjnego certyfikatu.',
            1161 => 'Numer seryjny certyfikatu jest za długi (przekroczono dopuszczalny rozmiar 64 znaków).',
            1162 => 'Wymagane parametry nie zostały podane w żądaniu (numer seryjny certyfikatu lub numer zamówienia).',
            1163 => 'W żądaniu podano parametry które nie mogą występować jednocześnie (numer seryjny certyfikatu i numer zamówienia).',
            1164 => 'Niepoprawna liczba parametrów identyfikujących certyfikat. Podany powinien być numer seryjny certyfikatu lub certyfikat w postaci PEM.',
            1165 => 'Niepoprawny format PEM.',
            1166 => 'Podany kod produktu nie jest kodem na odnowienie.',
            1167 => 'Profil certyfikatu do odnowienia różni się od profilu certyfikatu odnawianego.',
            1168 => 'CN certyfikatu różni się od CN certyfikatu odnawianego.',
            1169 => 'Nazwa użytkownika w odnawianym certyfikacie jest inna niż podana.',
            1170 => 'Odnawiany certyfikat został wystawiony przez innego partnera.',
            1172 => 'Żądanie zawiera nadmiarowe elementy. Należy zweryfikować poprawność żądania z dokumentacją.',
            1176 => 'Status zamówienia uniemożliwia wysłanie weryfikacji domeny. Zamówienie jest w trakcie realizacji lub zostało anulowane. Dla podanego zamówienia certyfikat został już wydany. Wprowadzenie zmian nie jest możliwe.',
            1181 => 'Podany kod produktu, nie jest kodem na wydanie certyfikatu.',
            1182 => 'Element verifyDomain/code nie został znaleziony.',
            1183 => 'Wartość z elementu verifyDomain/code przekroczyła dopuszczalny rozmiar 255 znaków.',
            1184 => 'Kod weryfikacji domeny już wygasł.',
            1186 => 'Kod weryfikacyjny jest niepoprawny.',
            1191 => 'Okres ważności przekracza maksymalny okres ważności wybranego produktu.',
            1194 => 'Element orderSNICertificate/orderSNIParameters/CSR nie został odnaleziony lub jest pusty.',
            1195 => 'Element orderSNICertificate/orderSNIParameters/CSR nie jest poprawnym żądaniem CSR.',
            1196 => 'Wartość z elementu orderSNICertificate/orderSNIParameters/language przekroczyła dopuszczalny rozmiar 2 znaków.',
            1197 => 'Element orderSNICertificate/orderSNIParameters nie został odnaleziony.',
            1198 => 'Element orderSNICertificate/serialNumbers nie został odnaleziony.',
            1199 => 'Podanie przynajmniej jednego z atrybutów orderSNICertificate/serialNumbers/serialNumber jest wymagane.',
            2000 => 'Element orderSNICertificate/serialNumbers/serialNumber nie może być pusty.',
            2001 => 'Wartosc elementu orderSNICertificate/serialNumbers/serialNumber przekroczyła dopuszczalny rozmiar 64 znaków.',
            2002 => 'Element orderSNICertificate/serialNumbers/serialNumber musi byc w postaci szesnastkowej.',
            2003 => 'Certyfikat o podanym numerze seryjnym wygasł lub został unieważniony.',
            2004 => 'Certyfikat SNI nie może zawierać innego cerrtyfikatu SNI.',
            2005 => 'Żaden z podanych certyfikatów nie zawiera domen.',
            2006 => 'Element orderSNICertificate/requestorInfo nie został odnaleziony.',
            2010 => 'Element orderSNICertificate/requestorInfo/email nie został odnaleziony.',
            2011 => 'Element orderSNICertificate/requestorInfo/firstName nie został odnaleziony.',
            2012 => 'Element orderSNICertificate/requestorInfo/lastName nie został odnaleziony.',
            2013 => 'Element orderSNICertificate/requestorInfo/phone nie został odnaleziony.',
            2016 => 'Adres e-mail z elementu orderSNICertificate/requestorInfo/email nie jest poprawny.',
            2020 => 'Wartość z elementu orderSNICertificate/requestorInfo/lastName przekroczyła dopuszczalny rozmiar 255 znaków.',
            2021 => 'Wartość z elementu orderSNICertificate/requestorInfo/phone przekroczyła dopuszczalny rozmiar 255 znaków.',
            2024 => 'Wartość z elementu orderSNICertificate/requestorInfo/firstName przekroczyła dopuszczalny rozmiar 255 znaków.',
            2025 => 'W celu złożenia zamówienia na produkt SNI Certificate należy użyć metody orderSNICertificate, modifySNICertificate',
            2026 => 'Wartość z elementu orderSNICertificate/requestorInfo/email przekroczyła dopuszczalny rozmiar 255 znaków.',
            2027 => 'Niepoprawna liczba parametrów identyfikujących certyfikat. Podany powinien być modifySNICertificate/serialNumber lub modifySNICertificate/X509Cert',
            2028 => 'Element modifySNICertificate/serialNumber nie może być pusty.',
            2029 => 'Wartosc elementu modifySNICertificate/serialNumber przekroczyla dopuszczalny rozmiar 64 znakow.',
            2030 => 'Element modifySNICertificate/serialNumber musi byc w postaci szesnastkowej.',
            2031 => 'Brak certyfikatu o numerze seryjnym podanym w elemencie modifySNICertificate/serialNumber.',
            2032 => 'Modyfikowany certyfikat musi być certyfikatem SNI.',
            2033 => 'Niepoprawny format PEM certyfikatu w elemencie modifySNICertificate/X509Cert.',
            2034 => 'Brak certyfikatu podanego w elemencie modifySNICertificate/X509Cert.',
            2035 => 'Podanie przynajmniej jednego z atrybutów modifySNICertificate/addSerialNumbers/serialNumber jest wymagane.',
            2036 => 'Element modifySNICertificate/addSerialNumbers/serialNumber nie może być pusty.',
            2037 => 'Wartosc elementu modifySNICertificate/addSerialNumbers/serialNumber przekroczyla dopuszczalny rozmiar 64 znakow.',
            2038 => 'Element modifySNICertificate/addSerialNumbers/serialNumber musi byc w postaci szesnastkowej.',
            2039 => 'Podanie przynajmniej jednego z atrybutów modifySNICertificate/removeSerialNumbers/serialNumber jest wymagane.',
            2040 => 'Element modifySNICertificate/removeSerialNumbers/serialNumber nie może być pusty.',
            2041 => 'Wartosc elementu modifySNICertificate/removeSerialNumbers/serialNumber przekroczyla dopuszczalny rozmiar 64 znakow.',
            2042 => 'Element modifySNICertificate/removeSerialNumbers/serialNumber musi byc w postaci szesnastkowej.',
            2043 => 'Nie można dodawać i usuwać tego samego certyfikatu.',
            2044 => 'Nie można dodać certyfikatu. Certyfikat nie został znaleziony.',
            2045 => 'Nie można dodać certyfikatu będącego certyfikatem SNI.',
            2046 => 'Nie można dodać certyfikatu, który już wchodzi w skład certyfikatu SNI.',
            2047 => 'Nie można usunąć certyfikatu, który nie wchodzi w skład certyfikatu SNI.',
            2048 => 'Wynikowy certyfikat nie zawiera domen.',
            2049 => 'Element verifyOrder/verifyOrderParameters/note nie został znaleziony lub jest pusty.',
            2050 => 'Wartość elementu verifyOrderParameters/note przekroczyła dopuszczalny rozmiar 227 znaków.',
            2051 => 'Niepoprawna wartość w polu CommonName.',
            2052 => 'Element getExpiringCertificates/validityDaysLeft nie został znaleziony lub ma niepoprawną wartość',
            2053 => 'Element cancelParameters nie został odnaleziony.',
            2054 => 'Element changeApprovers/Approver nie został odnaleziony.',
            2055 => 'Element orderID nie został odnaleziony.',
            2056 => 'Status zamówienia nie pozwala na dodanie notatki.',
            2057 => 'Wartość elementu toDate nie może być wcześniejsza od wartości elementu fromDate.',
            2058 => 'Atrybut Locality lub StateOfProvince nie został znaleziony.',
            2059 => 'Niepoprawna wartość w elemencie verificationNotificationEnabled',
            2061 => 'Niepoprawna wartość w elemencie renewCertificate/approvers/verificationNotificationEnabled',
            2063 => 'Element verifyOrder/verifyOrderParameters/documents/document nie został odnaleziony.',
            2064 => 'Element verifyOrder/verifyOrderParameters/documents/document/type nie został odnaleziony.',
            2065 => 'Element verifyOrder/verifyOrderParameters/documents/document/description nie został odnaleziony.',
            2066 => 'Element verifyOrder/verifyOrderParameters/documents/document/files nie został odnaleziony.',
            2067 => 'Element verifyOrder/verifyOrderParameters/documents/document/files/file nie został odnaleziony.',
            2068 => 'Element verifyOrder/verifyOrderParameters/documents/document/files/file/filename nie został odnaleziony.',
            2069 => 'Element verifyOrder/verifyOrderParameters/documents/document/files/file/content nie został odnaleziony.',
            2070 => 'Element verifyOrder/verifyOrderParameters/documents/document/files/file/content powinien być w base64.',
            2080 => 'Przekroczono dopuszczalny rozmiar dla żądania.',
            2081 => 'Element fileName nie może zawierać znaków: \ / : * ? " < > |',
            2082 => 'Wartość elementu fileName ma nieprawidłową długość. Dopuszczalna długość: od 3 do 255 znaków.',
            2083 => 'Typ dokumentu nie jest obsługiwany.',
            2085 => 'Jeden z plików w elemencie verifyOrder/verifyOrderParameters/documents/document/files/file przekroczył dopuszczalny rozmiar (30MB).',
            2088 => 'Długość części domeny z elementu SANEntries/SANEntry/DNSName przekroczyła dopuszczalny rozmiar znaków.',
            2089 => 'Algorytm nie jest skonfigurowany.',
            2090 => 'W elemencie hashAlgorithm znajduje się niepoprawna wartość.',
            2091 => 'Niepoprawna wartość w elemencie getProductList/HashAlgorithm.',
            2093 => 'Data ważności certyfikatu jest z przeszłości.',
            2094 => 'Certyfikat nie spełnia warunków reissue.',
            2095 => 'Element SANEntries/SANEntry/DNSName nie może być pusty.',
            2096 => 'Element serialNumber musi być w postaci szesnastkowej.',
            2097 => 'Element reissueCertificate/CSR nie jest poprawnym żądaniem CSR.',
            2104 => 'Data kompromitacji klucza może być podana jedynie dla przyczyny unieważnienia Kompromitacja klucza.',
            2109 => 'Niedozwolona długość klucza publicznego.',
            2121 => 'Wartość z elementu quickOrder/organizationInfo/verificationPhoneNumber przekroczyła dopuszczalny rozmiar 255 znaków.',
            2122 => 'Reissue dla produktów SimplySign jest niedostępny.',
            2124 => 'Nieobsługiwana funkcja skrótu.',
            2125 => 'CSR zawiera niepoprawny podpis.',
            2126 => 'Nie można wydać ponownie certyfikatu reissue dla tego samego certyfikatu.',
            2127 => 'Niepoprawna wartość w elemencie certificateDetails.',
            2128 => 'Niepoprawna wartość w elemencie orderDetails.',
            2129 => 'Niepoprawna wartość w elemencie order Status.',
            2130 => 'Element SANEntries/SANEntry/DNSName zawiera domenę istniejącą w wydanym certyfikacie.',
            2131 => 'Nie znaleziono zamówienia w bazie.',
            2137 => 'Niepoprawna wartość atrybutu businessCategory (BC).',
            2138 => 'Nie znaleziono atrybutu businessCategory (BC).',
            2139 => 'Atrybut StreetAddress nie został znaleziony.',
            2140 => 'Wartość atrybutu streetAddress (ST) przekroczyła 64 znaki.',
            2141 => 'Atrybut streetAddress (ST) musi być zakodowany jako UTF8String.',
            2142 => 'Atrybut PostalCode nie został znaleziony.',
            2143 => 'Wartość atrybutu postalCode (P) przekroczyła 40 znaków.',
            2144 => 'Wartość atrybutu postalCode (P) musi być typu PrintableString.',
            2153 => 'Zamówienie o podanym numerze nie zostało złożone przez API.',
            2154 => 'Niepoprawna wartość atrybutu postalCode (P).',
            2155 => 'Niepoprawna wartość atrybutu Jurisdiction of Incorporation State or Province Name (JoISoPN).',
            2156 => 'Niepoprawna wartość atrybutu stateOrProvinceName (SP).',
            2157 => 'Brakuje elementu approverMethod.',
            2158 => 'Zbyt wiele elementów. Można podać tylko jeden approverEmail lub approverEmailPrefix.',
            2159 => 'Wymagany element approverEmailPrefix nie został podany',
            2160 => 'Wymagany element approverEmail nie został podany.',
            2161 => 'VerifyDomain nie obsługuje wniosków multidomenowych.',
            2162 => 'Element SANApprover nie został odnaleziony.',
            2163 => 'Metoda nie obsługuje podanego typu produktu.',
            2164 => 'Atrybut SerialNumber poiada niepoprawną wartość.',
            2165 => 'Atrybut Joiln posiada nieproprawną wratość.',
            2166 => 'Atrybut Locality posiada niepoprawną wartość.',
            2167 => 'Atrybut OrganizationUnit posiada niepoprawną wartość.',
            2168 => 'Atrybut Organization posiada niepoprawną wartość',
            2169 => 'Atrybut streetAddress posiada niepoprawną wartość.',
            2170 => 'Atrybut Description ma nieprawidłową długość. Dopuszczalna długość: do 1000 znaków.',
            2171 => 'Metoda weryfikacji nie jest wspierana dla adresu IP.',
            2172 => 'E-mail kontaktowy o unieważnieniu jest taki sam jak login.',
            2173 => 'Wartość elementu orderParameters/revocationContactEmail jest nieprawidłowa.',
            2175 => 'Atrybut UnstructuredName lub UnstructuredAddress nie został znaleziony.',
            2176 => 'Atrybut UnstructuredName i UnstructuredAddress nie może występować razem.',
            2177 => 'Atrybut UnstructuredName musi być zakodowany jako PrintableString.',
            2178 => 'Atrybut UnstructuredAddress musi być zakodowany jako PrintableString.',
            2179 => 'Wartość atrybutu UnstructuredName przekroczyła dopuszczalny rozmiar 64 znaków.',
            2180 => 'Wartość atrybutu UnstructuredAddress przekroczyła dopuszczalny rozmiar 64 znaków.',
            2181 => 'Atrybut UnstructuredName nie jest prawidłową nazwą domeny.',
            2182 => 'Atrybut UnstructuredAddress nie jest prawidłowym adresem IP.',
            2183 => 'Atrybut Description musi być zakodowany jako UTF8String.',
            2184 => 'Wartość atrybutu Description przekroczyła dopuszczalny rozmiar 255 znaków.',
            2185 => 'Data podana w shortenedValidityPeriod lub ValidityPeriod/NotAfter jest z przeszłości.',
            2186 => 'Metoda weryfikacji nie jest obsługiwana dla dla zamówień zawierających domenę Wildcard.',
            2187 => 'W żądaniu podano przestarzałe pole ValidityPeriod. Aby skrócić okres ważności certyfikatu należy użyć shortenedValidityPeriod.',
            2188 => 'Wniosek reissue wymaga ponownej weryfikacji domen. W związku ze zmianami w w regulacjach dotyczących metod weryfikacji, istniejące weryfikacje nie mogą być ponownie wykorzystane.'
        )
    );
    
    /**
     * Returns an array with descriptions of errors that have occured.
     * 
     * The returned array is an array of arrays containing the following keys:
     * code, number, text, where code is a success code, number is a error
     * number and text is a description of an error.
     * 
     * @param string $lang
     * @param int $status
     * @param array $errors
     * @return array
     */
    public function getText($lang, $status, $errors) {
        $texts = array();
        if (empty($errors)) {
            $t = isset($this->texts_status[$lang][$status]) ? 
                    $this->texts_status[$lang][$status] : '';
            $texts[] = array(
                'code' => $status,
                'number' => NULL,
                'text' => $t
            );
        } else {
            foreach ($errors as $e) {
                $t = isset($this->texts_error[$lang][$e->errorCode]) ? 
                        $this->texts_error[$lang][$e->errorCode] : '';
                $v = empty($e->value) ? '' : ' ['.$e->value.']';
                $texts[] = array(
                    'code' => $status,
                    'number' => $e->errorCode,
                    'text' => $t.$v
                );
            }
        }
        return $texts;
    }
}
