<?php

/**
 * Partner API Library
 *
 * @copyright Copyright (c) 2020 Asseco Data Systems SA
 * @license license.txt
 */
/*
 * Utworzenie obietu usługi. Patrz plik start.php.
 */

require_once 'certumPartnerAPI/service.php';
$service = new PartnerAPIService('userName', 'password');

/*
 * Ważne:
 * Przed wywołaniem operacji quickOrder należy wywołać operację
 * validateOrderParameters w celu weryfikacji parametrów zamówienia.
 * Patrz plik z przykładem: validateOrderParameters.php.
 * Szczegóły dotyczące kolejności i wymagalności poszczególnych operacji
 * zawarte są w dokumentacji PDF dla usługi webowej.
 */

/*
 * Pobranie obiektu operacji quickOrder.
 */

$op = $service->operationQuickOrder();

/*
 * Ustawienie poszczególnych parametrów operacji.
 * Nie wszystkie parametry są obowiązkowe.
 * W szczególności ustawienie parametrów approver i SANEntry jest zależne
 * od rodzaju zamawianego produktu.
 */

require_once 'certumPartnerAPI/types/typeBusinessCategoryEnum.php';
require_once 'certumPartnerAPI/types/typeHashAlgorithmEnum.php';
require_once 'certumPartnerAPI/types/typeVerificationMethodType.php';
require_once 'certumPartnerAPI/types/typeApproverEmailPrefixType.php';

$csr = file_get_contents('/path/to/sample.csr');

$op->setCSR($csr)->setCustomer('A customer name')->setOrderID('12345')->setProductCode('721')
        ->setUserAgent('User agent')->setHashAlgorithm(PartnerAPITypeHashAlgorithmEnum::RSA_SHA1)->setEmail('abc@example.com');
$op->setRequestorInfo('Imie', 'Nazwisko', 'email@example.org', '11223344');
$op->setLanguage('pl')->setShortenedValidityPeriod('2021-12-01')
        ->setOrganizationInfo('Unizeto Technologies SA', '8520006444');
$op->setRevocationContactEmail('revocations@example.org');

/*
 * Dla nadpisywania pola commonName z CSR należy zmienić też domeny w SANEntry.
 */

$op->addSANEntry('domain-overrided.com');

/*
 * Przykład użycia metody FILE.
 */
$op->setApproverMethod(PartnerAPITypeVerificationMethodType::FILE);
$op->setApproverEmail('support@example.domain.com');

/*
 * Przykład użycia metody DNS.
 */
//$op->setApproverMethod(PartnerAPITypeVerificationMethodType::DNS);
//$op->setApproverEmail('support@example.domain.com');

/*
 * Przykład użycia metody EMAIL.
 */
//$op->setApproverMethod(PartnerAPITypeVerificationMethodType::EMAIL);
//$op->setApproverEmailPrefix(PartnerAPITypeApproverEmailPrefixType::HOSTMASTER);

$op->setVerificationNotificationEnabled(true);

$op->setCommonName('domain-overrided.com');
$op->setOrganization('overrided Organization');
$op->setOrganizationalUnit('overrided Organizational Unit');
$op->setLocality('overrided Locality');

/* Nowy kod kraju ISO 3166-1 alpha-2 */
$op->setCountry('GB');

$op->setState('overrided state');

$op->setSerialNumber('overrided Serial Number');
/* Wartość tylko w postaci enuma */
$op->setBusinessCategory(PartnerAPITypeBusinessCategoryEnum::PRIVATE_ORGANIZATION);
$op->setStreetAddress('overrided Street Address');
$op->setPostalCode('overrided Postal Code');

/* Nowy kod kraju ISO 3166-1 alpha-2 */
$op->setJoisocn('US');
$op->setJoiln('overrided JoI Locality');
$op->setJoisopn('overrided JoI State');

/*
 * Wywołanie operacji. W odpowiedzi dostajemy id zamówienia.
 */

if ($op->call())
    $id = $op->getOrderID();
else
    die("error");

/*
 * W odpowiedzi możemy dostać również kod weryfikacyjny dla domen jeżeli użyta została metoda FILE lub DNS.
 */

if ($op->call()) {
    $id = $op->getOrderID();
    $verification = $op->getSANVerification();

    if (!is_null($verification)) {
        print $verification->approverMethod;
        print $verification->code;
        print $verification->approverEmail;

        foreach ($verification->FQDNs->getDataAsArray() as $fqdn) {
            print $fqdn;
        }
    }
} else
    die("error");

/*
 * Uwaga:
 * Przed operacją quickOrder należy wykonać operację validateOrderParameters
 * i obie operacje przyjmują ten sam zestaw parametrów.
 * Dlatego obiekt operacji validateOrderParameters posiada metodę
 * prepareQuickOrderOperation() która zwraca obiekt operacji quickOrder
 * z przygotowanymi już parametrami.
 * Oczywiście nie ma sensu wywoływać tej metody, jeśli operacja
 * validateOrderParameters się nie powiodła.
 */

$op = $service->operationValidateOrderParameters();
// ustawienie parametrów i wywołanie operacji
$op2 = $op->prepareQuickOrderOperation();
// jeśli e-maile weryfikacyjne mają być wysyłane, należy to włączyć osobno
// ponieważ operacja ValidateOrderParameters nie posiada tej opcji
$op2->setVerificationNotificationEnabled(true);
if ($op2->call())
    $id = $op2->getOrderID();
else
    die("error");
