<?php
/**
 * Partner API Library
 *
 * @copyright Copyright (c) 2020 Asseco Data Systems SA
 * @license license.txt
 */

/*
 * Utworzenie obietu usługi. Patrz plik start.php.
 */

require_once 'certumPartnerAPI/service.php';
require_once 'certumPartnerAPI/types/typeVerificationMethodType.php';

$service = new PartnerAPIService('userName', 'password');

/*
 * Pobranie obiektu operacji reissueCertificate.
 */

$op = $service->operationReissueCertificate();

/*
 * Ustawienie poszczególnych parametrów operacji.
 * Nie wszystkie parametry są obowiązkowe.
 * Jednakże numer seryjny albo certyfikat w formacie PEM musi zostać podany.
 */

$csr = file_get_contents('/path/to/sample.csr');
$pem = file_get_contents('/path/to/sample.pem');

$op->setSerialNumber("1234")->setX509Cert($pem)->setHashAlgorithm('RSA-SHA1')->setCSR($csr);

/*
 * Dodanie nowej domeny do certyfikatu.
 */
$op->setApproverMethod(PartnerAPITypeVerificationMethodType::FILE);
$op->setApproverEmail('support@example.domain.com');
$op->setVerificationNotificationEnabled(true);
$op->addSANEntry('domain2.example2.com');
$op->addSANEntry('domain2.example3.com');


/*
 * Wywołanie operacji. W odpowiedzi dostajemy id zamówienia.
 */

if ($op->call())
    $id = $op->getOrderID();
else
    die("error");

/*
 * W odpowiedzi możemy dostać również kod weryfikacyjny dla domen jeżeli dodane zostały nowe domeny i użyta została metoda FILE lub DNS.
 */

if ($op->call()) {
    $id = $op->getOrderID();
    $verification = $op->getSANVerification();

    if (!is_null($verification)) {
        print $verification->approverMethod;
        print $verification->code;
        print $verification->approverEmail;

        foreach ($verification->FQDNs->getDataAsArray() as $fqdn) {
            print $fqdn;
        }
    }
} else
    die("error");
