<?php

/**
 * Partner API Library
 *
 * @copyright Copyright (c) 2020 Asseco Data Systems SA
 * @license license.txt
 */
/*
 * Utworzenie obietu usługi. Patrz plik start.php.
 */

require_once 'certumPartnerAPI/service.php';
$service = new PartnerAPIService('userName', 'password');

/*
 * Pobranie obiektu operacji validateOrderParameters.
 */

$op = $service->operationValidateOrderParameters();

/*
 * Ustawienie poszczególnych parametrów operacji.
 * Nie wszystkie parametry są obowiązkowe.
 * W szczególności ustawienie parametrów approver i SANEntry jest zależne
 * od rodzaju zamawianego produktu.
 */

require_once 'certumPartnerAPI/types/typeBusinessCategoryEnum.php';
require_once 'certumPartnerAPI/types/typeHashAlgorithmEnum.php';
require_once 'certumPartnerAPI/types/typeVerificationMethodType.php';
require_once 'certumPartnerAPI/types/typeApproverEmailPrefixType.php';

$csr = file_get_contents('/path/to/sample.csr');

$op->setCSR($csr)->setCustomer('A customer name')->setOrderID('12345')->setProductCode('721')
        ->setUserAgent('User agent')->setHashAlgorithm(PartnerAPITypeHashAlgorithmEnum::RSA_SHA1)->setEmail('abc@example.com');
$op->setRequestorInfo('Imie', 'Nazwisko', 'email@example.org', '11223344');
$op->setLanguage('pl')->setShortenedValidityPeriod('2021-12-01')
        ->setOrganizationInfo('Unizeto Technologies SA', '8520006444');

/*
 * Dla nadpisywania pola commonName z CSR należy zmienić też domeny w SANEntry i Approvers.
 */

$op->addSANEntry('domain-overrided.com');

/*
 * Przykład użycia metody FILE.
 */
$op->setApproverMethod(PartnerAPITypeVerificationMethodType::FILE);
$op->setApproverEmail('support@example.domain.com');

/*
 * Przykład użycia metody DNS.
 */
//$op->setApproverMethod(PartnerAPITypeVerificationMethodType::DNS);
//$op->setApproverEmail('support@example.domain.com');

/*
 * Przykład użycia metody EMAIL.
 */
//$op->setApproverMethod(PartnerAPITypeVerificationMethodType::EMAIL);
//$op->setApproverEmailPrefix(PartnerAPITypeApproverEmailPrefixType::HOSTMASTER);

$op->setCommonName('domain-overrided.com');
$op->setOrganization('overrided Organization');
$op->setOrganizationalUnit('overrided Organizational Unit');
$op->setLocality('overrided Locality');

/* Nowy kod kraju ISO 3166-1 alpha-2 */
$op->setCountry('GB');

$op->setState('overrided state');

$op->setSerialNumber('overrided Serial Number');
/* Wartość tylko w postaci enuma */
$op->setBusinessCategory(PartnerAPITypeBusinessCategoryEnum::PRIVATE_ORGANIZATION);
$op->setStreetAddress('overrided Street Address');
$op->setPostalCode('overrided Postal Code');

/* Nowy kod kraju ISO 3166-1 alpha-2 */
$op->setJoisocn('US');
$op->setJoiln('overrided JoI Locality');
$op->setJoisopn('overrided JoI State');

if ($op->call())
    $p = $op->getParsedCSR();
else
    die("error");

/*
 * Teraz można odczytać poszczególne pola sparsowanego pliku CSR.
 * Są to albo wartości typu string albo null.
 */

print $p->commonName;
print $p->country;
print $p->email;
print $p->joILN;
print $p->joISoCN;
print $p->joISoPN;
print $p->businessCategory;
print $p->locality;
print $p->organization;
print $p->organizationalUnit;
print $p->postalCode;
print $p->serialNumber;
print $p->state;
print $p->streetAddress;
